<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ko">
<context>
    <name>AuthFace</name>
    <message>
        <source>Face ID</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>확인 성공</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation type="unfinished"><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Verify your Face ID</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Face ID locked, use password please</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Device unavailable!</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AuthFingerprint</name>
    <message>
        <source>Verify your fingerprint</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>확인 성공</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation type="unfinished"><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Fingerprint locked, use password please</source>
        <translation>지문 잠김, 비밀번호를 사용하십시오</translation>
    </message>
</context>
<context>
    <name>AuthIris</name>
    <message>
        <source>Iris ID</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>확인 성공</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation type="unfinished"><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Verify your Iris ID</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Iris ID locked, use password please</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AuthPasskey</name>
    <message>
        <source>Please plug in the security key</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Verification successful</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Verification failed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Identifying the security key</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AuthPassword</name>
    <message>
        <source>Verification successful</source>
        <translation>확인 성공</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation type="unfinished"><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>잘못된 비밀번호</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>비밀번호</translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation type="unfinished"/>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation type="unfinished"><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation>비밀번호 초기화</translation>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AuthSingle</name>
    <message>
        <source>Please try again 1 minute later</source>
        <translation type="unfinished"/>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation type="unfinished"><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation>비밀번호 초기화</translation>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AuthUKey</name>
    <message>
        <source>Verification successful</source>
        <translation>확인 성공</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation type="unfinished"><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Wrong PIN</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>UKey is required</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enter your PIN</source>
        <translation type="unfinished"/>
    </message>
    <message numerus="yes">
        <source>Please try again %n minute(s) later</source>
        <translation type="unfinished"><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation type="unfinished"/>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation type="unfinished"><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>AuthWidget</name>
    <message>
        <source>Account</source>
        <translation>계정</translation>
    </message>
    <message numerus="yes">
        <source>Your password will expire in %n days, please change it timely</source>
        <translation type="unfinished"><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Password expired, please change</source>
        <translation>비밀번호가 만료되었습니다. 변경하십시오</translation>
    </message>
    <message>
        <source>Your password has expired. Please contact the administrator to change it</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Terminal locked, please contact administrator</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DeepinAuthFramework</name>
    <message>
        <source>Wrong Password</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>GreeterWorker</name>
    <message>
        <source>Wrong account</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>잘못된 비밀번호</translation>
    </message>
</context>
<context>
    <name>InhibitWarnView</name>
    <message>
        <source>Cancel</source>
        <translation>취소</translation>
    </message>
    <message>
        <source>The reason of inhibit.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>LighterGreeter</name>
    <message>
        <source>Standard Mode</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>LockContent</name>
    <message>
        <source>Lock Screen</source>
        <translation>잠금 화면</translation>
    </message>
    <message>
        <source>Failed to lock screen</source>
        <translation>화면 잠금 실패</translation>
    </message>
</context>
<context>
    <name>LockWorker</name>
    <message>
        <source>Fingerprint verification timed out, please enter your password manually</source>
        <translation>지문 확인 시간이 초과되었습니다. 비밀번호를 직접 입력하여 주십시오.</translation>
    </message>
    <message>
        <source>Failed to match fingerprint</source>
        <translation>지문 일치 실패</translation>
    </message>
</context>
<context>
    <name>MultiUsersWarningView</name>
    <message>
        <source>Cancel</source>
        <translation>취소</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to shutdown, are you sure you want to shut down?</source>
        <translation>위의 사용자가 여전히 로그인되어 있고 종료로 인해 데이터가 손실됩니다. 종료하시겠습니까?</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to reboot, are you sure you want to reboot?</source>
        <translation>위의 사용자가 계속 로그인되어 있고 재부팅으로 인해 데이터가 손실됩니다. 재부팅하시겠습니까?</translation>
    </message>
</context>
<context>
    <name>SessionWidget</name>
    <message>
        <source>You have enabled the high system security level, thus cannot switch to the Wayland mode, please disable the high security level in Security Center and try again.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ShutdownWidget</name>
    <message>
        <source>Shut down</source>
        <translation>컴퓨터 끄기</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>재부팅</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>대기모드</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>최대 절전 모드</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>잠금</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>로그아웃</translation>
    </message>
    <message>
        <source>Switch user</source>
        <translation>사용자 전환</translation>
    </message>
    <message>
        <source>Switch system</source>
        <translation>전환 시스템</translation>
    </message>
    <message>
        <source>Update and Shut Down</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Update and Reboot</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SystemMonitor</name>
    <message>
        <source>Start system monitor</source>
        <translation>시스템 모니터링 시작하기</translation>
    </message>
</context>
<context>
    <name>UdcpMFALoginWidget</name>
    <message>
        <source>发送验证码</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>请输入手机号</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>请输入验证码</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>获取验证码</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UpdateWorker</name>
    <message>
        <source>Update</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please plug in and then install updates.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UsersWithTheSameName</name>
    <message>
        <source>Return</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please select the account for login</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Local Account</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Domain Account</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>WarningContent</name>
    <message>
        <source>The programs are preventing the computer from shutting down, and forcing shut down may cause data loss.</source>
        <translation>이 프로그램이 컴퓨터를 종료하지 못하게 하고 있으며, 강제로 종료하면 데이터가 손실될 수 있습니다.</translation>
    </message>
    <message>
        <source>To close the program, click Cancel, and then close the program.</source>
        <translation>프로그램을 닫려면 취소를 클릭한 다음 프로그램을 닫습니다.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from reboot, and forcing reboot may cause data loss.</source>
        <translation>이 프로그램이 컴퓨터를 재부팅하지 못하게 하고 있으며, 강제로 재부팅하면 데이터가 손실될 수 있습니다.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from suspend, and forcing suspend may cause data loss.</source>
        <translation>이 프로그램은 컴퓨터가 일시 중단되는 것을 방지하고, 강제로 일시 중단하면 데이터 손실이 발생할 수 있습니다.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from hibernate, and forcing hibernate may cause data loss.</source>
        <translation>이 프로그램으로 인해 컴퓨터가 최대 절전 모드로 전환되지 않으며, 최대 절전 모드로 전환하면 데이터가 손실될 수 있습니다.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from log out, and forcing log out may cause data loss.</source>
        <translation>이 프로그램으로 인해 컴퓨터가 로그아웃되지 않으며, 강제로 로그아웃하면 데이터가 손실될 수 있습니다.</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>컴퓨터 끄기</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>재부팅</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>대기모드</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>최대 절전 모드</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>로그아웃</translation>
    </message>
    <message>
        <source>Are you sure you want to shut down?</source>
        <translation>종료 하시겠습니까?</translation>
    </message>
    <message>
        <source>Are you sure you want to reboot?</source>
        <translation>재부팅 하시겠습니까?</translation>
    </message>
    <message>
        <source>Are you sure you want to log out?</source>
        <translation>로그 아웃 하시겠습니까?</translation>
    </message>
    <message>
        <source>Update and Shut Down</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Update and Reboot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Closing the programs and shutting down, please wait...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Closing the programs and rebooting, please wait...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Closing the programs and logging out, please wait...</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dss::module::AssistLoginWidget</name>
    <message>
        <source>Automatic login</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Turn on</source>
        <translation>켜기</translation>
    </message>
    <message>
        <source>Turn off</source>
        <translation>끄기</translation>
    </message>
</context>
</TS>